@@ -299,7 +299,7 @@ public:
                 painter->drawRoundedRect(shadowRect, 3.0, 3.0);
 
                 // draw rounded rect itself
-                painter->setBrush(option.palette.button());
+                painter->setBrush(option.palette.window());
                 painter->drawRoundedRect(outputRect, 3.0, 3.0);
 
                 painter->restore();
@@ -478,7 +478,7 @@ void KCommandBarPrivate::slotReturnPressed(KCommandBar *q)
 
 void KCommandBarPrivate::setLastUsedActions()
 {
-    auto cfg = KSharedConfig::openConfig();
+    auto cfg = KSharedConfig::openStateConfig();
     KConfigGroup cg(cfg, "General");
 
     QStringList actionNames = cg.readEntry(QStringLiteral("CommandBarLastUsedActions"), QStringList());
@@ -576,6 +576,18 @@ KCommandBar::KCommandBar(QWidget *parent)
     });
 
     setHidden(true);
+
+    // Migrate last used action config to new location
+    auto cfg = KSharedConfig::openConfig();
+    KConfigGroup cg(cfg, "General");
+
+    QStringList actionNames = cg.readEntry(QStringLiteral("CommandBarLastUsedActions"), QStringList());
+
+    auto stateCfg = KSharedConfig::openStateConfig();
+    KConfigGroup stateCg(stateCfg, "General");
+    stateCg.writeEntry(QStringLiteral("CommandBarLastUsedActions"), actionNames);
+
+    cg.deleteEntry(QStringLiteral("CommandBarLastUsedActions"));
 }
 
 /**
@@ -584,7 +596,7 @@ KCommandBar::KCommandBar(QWidget *parent)
 KCommandBar::~KCommandBar()
 {
     auto lastUsedActions = d->lastUsedActions();
-    auto cfg = KSharedConfig::openConfig();
+    auto cfg = KSharedConfig::openStateConfig();
     KConfigGroup cg(cfg, "General");
     cg.writeEntry("CommandBarLastUsedActions", lastUsedActions);
 
@@ -611,11 +623,14 @@ void KCommandBar::setActions(const QVector<ActionGroup> &actions)
 void KCommandBar::show()
 {
     QRect parentGeometry;
+    bool isInMainWindow = false;
     if (const QWidget *parent = parentWidget()) {
         parentGeometry = parent->geometry();
-        if (const QMainWindow *window = qobject_cast<const QMainWindow *>(parent)) {
+        const QMainWindow *window = qobject_cast<const QMainWindow *>(parent);
+        if (window && window->centralWidget()) {
             parentGeometry.setTop(window->mapToGlobal(window->centralWidget()->pos()).y());
             parentGeometry.setHeight(window->centralWidget()->height());
+            isInMainWindow = true;
         }
     } else {
         parentGeometry = screen()->availableGeometry();
@@ -634,6 +649,11 @@ void KCommandBar::show()
     // resize() doesn't work here, so use setFixedSize() instead
     setFixedSize(size);
 
+    if (!isInMainWindow && parentWidget()) {
+        const int y = std::max(0, (parentGeometry.height() - size.height()) * 1 / 6);
+        parentGeometry.setTop(y);
+    }
+
     // set the position to the top-center of the parent
     // just below the menubar/toolbar (if any)
     const QPoint position{parentGeometry.center().x() - size.width() / 2, parentGeometry.y()};
